config

package
v0.0.0-...-b1be0e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2020 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InitDB

func InitDB(config *ConfigurationModel) (*mongo.Client, error)

InitDB will create a variable that represent the mongo.Client

func InitLog

func InitLog() *logrus.Entry

InitLog will create a variable that represent the logrus.Entry

Types

type ConfigurationModel

type ConfigurationModel struct {
	Port    string `json:"port"`
	MongoDB struct {
		Addr     string `json:"addr"`
		Database string `json:"database"`
	} `json:"mongo_db"`
}

ConfigurationModel represent the configuration model

func InitConfig

func InitConfig() (*ConfigurationModel, error)

Jump to